.. examples:

########
Examples
########


Code Examples
-------------

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Code examples

   basic_worklist
   display
   mpps
   print
   qr_find
   qr_get
   qr_move
   relevant_patient
   storage
   verification

* :doc:`Basic Worklist Management (C-FIND) <basic_worklist>`
* :doc:`Display System Management (N-GET) <display>`
* Modality Performed Procedure Step Management

  * :doc:`MPPS (N-CREATE and N-SET) <mpps>`
* Print Management

  * :doc:`Basic Grayscale Print Management (N-CREATE, N-SET, N-GET, N-DELETE, N-ACTION) <print>`
* Query/Retrieve

  * :doc:`Query/Retrieve - Find (C-FIND) <qr_find>`
  * :doc:`Query/Retrieve - Get (C-GET and C-STORE) <qr_get>`
  * :doc:`Query/Retrieve - Move (C-MOVE and C-STORE) <qr_move>`
* :doc:`Relevant Patient Information Query (C-FIND) <relevant_patient>`
* :doc:`Storage (C-STORE) <storage>`
* :doc:`Verification (C-ECHO) <verification>`


Example applications
--------------------

.. toctree::
   :maxdepth: 1
   :caption: Example applications

   ../apps/echoscp
   ../apps/echoscu
   ../apps/findscu
   ../apps/getscu
   ../apps/movescu
   ../apps/qrscp
   ../apps/storescp
   ../apps/storescu
